# pygmes is a wraper for GeneMark-ES

This project aims at making GeneMark-ES more usable. By default 
GeneMark-ES has some problems with fragmented and incomplete genomes.

For metagenomic analysis this is an issue, thus I developed pygmes.

## Status
Currently this project is very much WIP, so do expect problems and
incomplete documentation.

It is just on pip already as it is a suggested package for EukCC (https://github.com/Finn-Lab/EukCC/)

